@@ -1,4 +1,5 @@
 #!/bin/bash
 # checkout (update) all of the outputs to revert to what is on github
-. ./targets.sh
-git checkout $TGTS
+
+git checkout docs
+ls linkml_model | grep -v model | xargs git checkout
